@@ -3,6 +3,14 @@ use Date::Simple 3;
 use base qw/Date::Simple/;
 use overload '""' => '_format' ;
 
+*EXPORT      = *Date::Simple::EXPORT;
+*EXPORT_OK   = *Date::Simple::EXPORT_OK;
+*EXPORT_TAGS = *Date::Simple::EXPORT_TAGS;
+
+sub d8    { __PACKAGE__->_d8(@_)    }
+sub today { __PACKAGE__->_today(@_) }
+sub ymd   { __PACKAGE__->_ymd(@_)   }
+
 sub new {
     my ($class,$fmt,@args)=@_;
     my $self=$class->SUPER::new(@args);
